@@ -4,11 +4,11 @@ use 5.010001;
 use Log::Any '$log';
 use Moo;
 
-use Locale::TextDomain 'Perinci-To-Doc';
+use Locale::TextDomain::UTF8 'Perinci-To-Doc';
 
 extends 'Perinci::Sub::To::FuncBase';
 
-our $VERSION = '0.39'; # VERSION
+our $VERSION = '0.40'; # VERSION
 
 sub BUILD {
     my ($self, $args) = @_;
@@ -246,7 +246,7 @@ Perinci::Sub::To::POD - Generate POD documentation from Rinci function metadata
 
 =head1 VERSION
 
-version 0.39
+version 0.40
 
 =head1 SYNOPSIS
 
